@@ -3,8 +3,10 @@
  */
 package org.gcube.portlets.user.tdtemplate.client.template.view;
 
+import java.util.ArrayList;
+import java.util.List;
+
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
-import org.gcube.portlets.user.td.widgetcommonevent.shared.expression.C_ExpressionContainer;
 import org.gcube.portlets.user.tdtemplate.client.TdTemplateController;
 import org.gcube.portlets.user.tdtemplate.client.event.ExpressionDialogOpenedEvent;
 import org.gcube.portlets.user.tdtemplate.client.resources.TdTemplateAbstractResources;
@@ -16,6 +18,7 @@ import org.gcube.portlets.user.tdtemplate.client.template.view.external.Expressi
 import org.gcube.portlets.user.tdtemplate.shared.SPECIAL_CATEGORY_TYPE;
 import org.gcube.portlets.user.tdtemplate.shared.TdTColumnCategory;
 import org.gcube.portlets.user.tdtemplate.shared.TdTDataType;
+import org.gcube.portlets.user.tdtemplate.shared.TemplateExpression;
 
 import com.extjs.gxt.ui.client.event.SelectionChangedEvent;
 import com.extjs.gxt.ui.client.event.SelectionChangedListener;
@@ -31,7 +34,7 @@ import com.google.gwt.user.client.ui.Label;
  * @Jan 16, 2014
  *
  */
-public class ColumnDefinitionView implements ColumnDefinition{
+public class ColumnDefinitionView implements ColumnDefinition, UserActionInterface, ColumnElement{
 	
 	private int columnIndex;
 	private Text columnHeaderValue = new Text();
@@ -45,9 +48,11 @@ public class ColumnDefinitionView implements ColumnDefinition{
 	
 	private SmartAddRuleButton buttonSmartAddRule = new SmartAddRuleButton();
 	private ExpressionDialogMng expressionDialogMng;
-	private C_ExpressionContainer ruleExpression = null;
-	private SPECIAL_CATEGORY_TYPE selectedCategoryType = SPECIAL_CATEGORY_TYPE.NONE;
 	
+	private List<TemplateExpression> rulesExpression = null;
+	
+//	private C_ExpressionContainer ruleExpression = null;
+	private SPECIAL_CATEGORY_TYPE selectedCategoryType = SPECIAL_CATEGORY_TYPE.NONE;
 	
 	/**
 	 * @param templatePanel 
@@ -109,10 +114,12 @@ public class ColumnDefinitionView implements ColumnDefinition{
 				
 				switch (selectedCategoryType) {
 					case DIMENSION:
-						templatePanel.setWidgetIntoTable(2, columnIndex, new Html("Choose Reference"));
+//						templatePanel.setWidgetIntoTable(2, columnIndex, new Html("Choose Reference"));
+						templatePanel.setWidgetIntoTable(2, columnIndex, new Html("Rule (unavailable)"));
 						break;
 						
 					case TIMEDIMENSION:
+						templatePanel.setWidgetIntoTable(2, columnIndex, new Html("Rule (unavailable)"));
 //						buttonSmartAddRule.update("Rule", TdTemplateAbstractResources.dataType());
 //						templatePanel.setWidgetIntoTable(2, columnIndex, buttonSmartAddRule);
 						break;
@@ -182,8 +189,8 @@ public class ColumnDefinitionView implements ColumnDefinition{
 				}
 				descr+=sel.getLabel();
 				
-				templatePanel.clearCell(2, columnIndex); //REMOVE Choose Reference
-				updateColumnDescription("Added reference:", descr, false);
+//				templatePanel.clearCell(2, columnIndex); //REMOVE Choose Reference
+				updateColumnDescription("Added reference:", descr, false, false);
 			}
 			
 			
@@ -241,6 +248,7 @@ public class ColumnDefinitionView implements ColumnDefinition{
 	public void resetDescriptionCell(){
 		templatePanel.clearCell(3, columnIndex); //IF EXISTS REMOVE DESCRIPTION ROW
 		expressionDialogMng = null; //RESET RULE DIALOG
+		resetRulesExpressions();
 	}
 	
 	public void resetEditRuleCell(){
@@ -248,15 +256,26 @@ public class ColumnDefinitionView implements ColumnDefinition{
 		expressionDialogMng = null; //RESET RULE DIALOG
 	}
 	
-	public void addRule(C_ExpressionContainer expression){
-		this.ruleExpression = expression;
-		updateColumnDescription("Added Rule:", ruleExpression.getReadableExpression(), true);
+	public void resetRulesExpressions(){
+		this.rulesExpression.clear();
+	}
+	
+	public void addRule(TemplateExpression expression, boolean isEditable, boolean isDeletable){
+
+		if(this.rulesExpression==null)
+			this.rulesExpression = new ArrayList<TemplateExpression>();
+			
+		resetRulesExpressions();
+		
+		this.rulesExpression.add(expression);
+			
+		updateColumnDescription("Added Rule:", expression.getHumanDescription(), isDeletable, isEditable);
 		
 	}
 	
-	public void updateColumnDescription(String title, String descr, boolean isDeletable){
+	public void updateColumnDescription(String title, String descr, boolean isDeletable, boolean isEditable){
 		
-		SmartButtonDescription button = new SmartButtonDescription(title, descr, this, isDeletable);
+		SmartButtonDescription button = new SmartButtonDescription(title, descr, this, isDeletable, isEditable);
 //		SmartHtmlDiv ruleDescription = new SmartHtmlDiv("Added Rule:", descr, null);
 		templatePanel.setWidgetIntoTable(3, columnIndex, button);
 	}
@@ -310,21 +329,12 @@ public class ColumnDefinitionView implements ColumnDefinition{
 		isValid = bool;
 	}
 
-	@Override
-	public String getColumnId() {
-		// TODO Auto-generated method stub
-		return null;
-	}
-
 	@Override
 	public TdTColumnCategory getSelectedColumnCategory() {
 		return setColumnTypeDialogManager.getCategorySelected();
 	}
 
-	public C_ExpressionContainer getRuleExpression() {
-		return ruleExpression;
-	}
-
+	
 	/* (non-Javadoc)
 	 * @see org.gcube.portlets.user.tdtemplate.client.template.ColumnDefinition#setCategoryType(org.gcube.portlets.user.tdtemplate.shared.CATEGORY_TYPE)
 	 */
@@ -368,4 +378,67 @@ public class ColumnDefinitionView implements ColumnDefinition{
 		return setColumnTypeDialogManager.getSelectedPeriodType();
 	}
 
+	
+	public List<TemplateExpression> getRulesExpression() {
+		return rulesExpression;
+	}
+
+	public void setRulesExpression(List<TemplateExpression> rulesExpression) {
+		this.rulesExpression = rulesExpression;
+	}
+	
+	@Override
+	public String getColumnId() {
+		return null;
+	}
+	
+	public void setAsReadOnly(boolean enabled){
+		
+		setColumnTypeDialogManager.getScbCategory().setReadOnly(enabled);
+		setColumnTypeDialogManager.getScbDataType().setReadOnly(enabled);
+		setColumnTypeDialogManager.getScbLocales().setReadOnly(enabled);
+		setColumnTypeDialogManager.getScbPeriodTypes().setReadOnly(enabled);
+		setColumnTypeDialogManager.getScbReference().setReadOnly(enabled);
+		
+//		buttonSmartAddRule.enable(!enabled);
+		
+	}
+	
+	
+	public void setColumnTypeAsReadOnly(boolean enabled){
+		setColumnTypeDialogManager.getScbCategory().setReadOnly(enabled);
+		setColumnTypeDialogManager.getScbDataType().setReadOnly(enabled);
+	}
+
+	/* (non-Javadoc)
+	 * @see org.gcube.portlets.user.tdtemplate.client.template.view.ActionInterface#editClicked()
+	 */
+	@Override
+	public void editClicked() {
+	}
+
+	/* (non-Javadoc)
+	 * @see org.gcube.portlets.user.tdtemplate.client.template.view.ActionInterface#cancelClicked()
+	 */
+	@Override
+	public void deleteClicked() {
+		resetDescriptionCell();
+	}
+
+	/* (non-Javadoc)
+	 * @see org.gcube.portlets.user.tdtemplate.client.template.view.ColumnElement#getColumnDataType()
+	 */
+	@Override
+	public String getColumnDataType() {
+		return this.getSelectedColumnCategory().getName();
+	}
+
+	/* (non-Javadoc)
+	 * @see org.gcube.portlets.user.tdtemplate.client.template.view.ColumnElement#getColumnType()
+	 */
+	@Override
+	public String getColumnType() {
+		return this.getSelectedColumnCategory().getId();
+	}
+
 }
